<?php

declare(strict_types=1);

namespace Drupal\cas_user_ban\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\PagerSelectExtender;
use Drupal\Core\Datetime\DateFormatterInterface;

/**
 * Displays the banned users list.
 */
class BannedUsersListController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    protected readonly Connection $connection,
    protected readonly DateFormatterInterface $dateFormatter,
  ) {}

  /**
   * Builds the response.
   */
  public function __invoke(): array {
    $build['banned_users_list'] = [
      '#theme' => 'table',
      '#header' => [
        'cas_username' => [
          'data' => $this->t('CAS username'),
        ],
        'timestamp' => [
          'data' => $this->t('Banned on'),
        ],
      ],
      '#empty' => $this->t('No CAS usernames banned.'),
    ];

    $query = $this->connection->select('cas_user_ban', 'b')
      ->fields('b', ['cas_username', 'timestamp'])
      ->orderBy('b.timestamp', 'DESC')
      ->extend(PagerSelectExtender::class)
      ->limit(20);

    $banned_users = $query->execute()->fetchAll();

    foreach ($banned_users as $banned_user) {
      $build['banned_users_list']['#rows'][] = [
        'cas_username' => [
          'data' => $banned_user->cas_username,
        ],
        'timestamp' => [
          'data' => $this->dateFormatter->format($banned_user->timestamp, 'medium'),
        ],
      ];
    }

    $build[] = ['#type' => 'pager'];

    return $build;
  }

}
