<?php

declare(strict_types=1);

namespace Drupal\cas_user_ban_test\Hook;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Class for testing user cancel form methods access.
 */
final class UserCancelHooks {

  use StringTranslationTrait;

  /**
   * Implements hook_form_FORM_ID_alter().
   *
   * @param array $form
   *   The build form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  #[Hook('form_user_cancel_form_alter')]
  public function alter(array &$form, FormStateInterface $form_state): void {
    $form['user_cancel_method']['user_cancel_reassign']['#access'] = FALSE;
  }

  /**
   * Implements hook_user_cancel_methods_alter().
   *
   * @param array $methods
   *   The methods to alter.
   */
  #[Hook('user_cancel_methods_alter')]
  public function cancelMethods(array &$methods): void {
    $methods['test_cancel_method'] = [
      'title' => $this->t('Test cancel method.'),
      'description' => $this->t('A test cancel method to verify possibility of adding custom methods.'),
    ];
  }

}
